@@ -3,7 +3,10 @@ from .events import Event, EpsilonEvent, StateEvent
 from .machines import Moore
 
 __all__ = (
-    TransitionsImplementationError, StateEventImplementationError,
-    Event, EpsilonEvent, StateEvent,
-    Moore
+    TransitionsImplementationError,
+    StateEventImplementationError,
+    Event,
+    EpsilonEvent,
+    StateEvent,
+    Moore,
 )
