@@ -3,18 +3,16 @@ from abc import ABC, abstractmethod
 
 
 class EventInterface(ABC):
-
     def __repr__(self):
         raise NotImplementedError
 
 
 class Event(EventInterface):
-
-    def __init__(self, *args, **kwargs):
+    def __init__(self):
         self.__name = self.__class__.__name__
 
     def __repr__(self):
-        return f'({self.__name}, {id(self)})'
+        return f"({self.__name}, {id(self)})"
 
 
 class StateEvent(Event):
@@ -37,10 +35,10 @@ class StateEvent(Event):
             if len(states) > 1:
                 raise StateEventImplementationError
             func, substates = next(iter(states.items()))
-            if func not in {'or', 'and', 'not'}:
+            if func not in {"or", "and", "not"}:
                 raise StateEventImplementationError
             else:
-                if func in {'or', 'and'}:
+                if func in {"or", "and"}:
                     if type(substates) is not list:
                         raise StateEventImplementationError
                     elif len(substates) < 2:
@@ -59,11 +57,9 @@ class StateEvent(Event):
 
 
 class EpsilonEvent(Event):
-
-    def __init__(self, event: Event, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, event: Event, ):
+        super().__init__()
         self.event = event
 
     def __getattr__(self, attr):
         return getattr(self.event, attr)
-
